@@ -5,7 +5,7 @@
 import json
 from collections import defaultdict
 
-from graphviz.dot import Digraph
+from graphviz import Digraph
 from prettytable import PrettyTable
 
 from quark.utils.colors import green, red
